Test if files would be ignored by .gitignore rules
Arguments
- path
A character vector of paths to test within the repo
- repo
The path to the git repository. If the directory is not a repository, parent directories are considered (see
git_find()). To disable this search, provide the filepath protected withI(). When using this parameter, always explicitly call by name (i.e.repo =) because future versions of gert may have additional parameters.
See also
usethis::use_git_ignore() to add a path to .gitignore.
Other git:
git_archive,
git_branch(),
git_commit(),
git_config(),
git_diff(),
git_fetch(),
git_history,
git_merge(),
git_rebase(),
git_remote,
git_repo,
git_reset(),
git_revert(),
git_signature(),
git_stash,
git_tag,
git_worktree