| git_repo | R Documentation |
git_init() creates a new repository
git_find() to discover an existing local repository.
git_info() shows basic information about a repository, such as the SHA
and branch of the current HEAD.
git_init(path = ".", bare = FALSE)
git_find(path = ".")
git_info(repo = ".")
path |
the location of the git repository, see the "path" section. |
bare |
if true, a Git repository without a working directory is created |
repo |
The path to the git repository. If the directory is not a
repository, parent directories are considered (see |
git_find() and git_init(): the path to the Git repository.
git_info(): A list of information of the Git repository.
For git_init() the path parameter sets the directory of the git repository
to create. If this directory already exists, it must be empty. If it does
not exist, it is created, along with any intermediate directories that don't
yet exist.
For git_find(), the path parameter specifies the directory at
which to start the search for a git repository. If it is not a git repository
itself, then its parent directory is consulted, then the parent's parent, and
so on.
If git_info()$shorthand is equal to HEAD,
it means the repository is in a detached head state.
Other git:
git_archive,
git_branch(),
git_commit(),
git_config(),
git_diff(),
git_fetch(),
git_history,
git_ignore,
git_merge(),
git_rebase(),
git_remote,
git_reset(),
git_restore(),
git_revert(),
git_signature(),
git_stash,
git_tag,
git_worktree
# directory does not yet exist
r <- tempfile(pattern = "gert")
git_init(r)
git_find(r)
git_info(r)
# create a child directory, then a grandchild, then search
r_grandchild_dir <- file.path(r, "aaa", "bbb")
dir.create(r_grandchild_dir, recursive = TRUE)
git_find(r_grandchild_dir)
# cleanup
unlink(r, recursive = TRUE)
# directory exists but is empty
r <- tempfile(pattern = "gert")
dir.create(r)
git_init(r)
git_find(r)
# cleanup
unlink(r, recursive = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.