View changes in a commit or in the current working directory.
git_diff()returns a data frame with information about a commit patch.git_diff_patch()is shortcode forgit_diff()$patch.
Arguments
- ref
a reference such as
"HEAD", or a commit id, orNULLto the diff the working directory against the repository index.- repo
The path to the git repository. If the directory is not a repository, parent directories are considered (see
git_find()). To disable this search, provide the filepath protected withI(). When using this parameter, always explicitly call by name (i.e.repo =) because future versions of gert may have additional parameters.
Related libgit2 documentation
diff.