| git_history | R Documentation |
git_commit_stats() returns information about commit insertion and deletion
git_commit_info() a list of commit info
git_commit_id() is a shortcut for git_commit_info()$id
git_log() shows the most recent commits
git_ls() lists all the files that are being tracked in the repository.
git_stat_files() shows information of when files was last modified.
git_commit_info(ref = "HEAD", repo = ".")
git_commit_id(ref = "HEAD", repo = ".")
git_commit_stats(ref = "HEAD", repo = ".")
git_log(ref = "HEAD", max = 100, after = NULL, path = NULL, repo = ".")
git_stat_files(files, ref = "HEAD", max = NULL, repo = ".")
ref |
revision string with a branch/tag/commit value |
repo |
The path to the git repository. If the directory is not a
repository, parent directories are considered (see |
max |
lookup at most latest n parent commits |
after |
date or timestamp: only include commits starting this date |
path |
character vector with paths to filter on; only commits that touch these paths are included |
files |
vector of paths relative to the git root directory.
Use |
git_commit_info() and git_commit_stats() return a list.
Other git:
git_archive,
git_branch(),
git_commit(),
git_config(),
git_diff(),
git_fetch(),
git_ignore,
git_merge(),
git_rebase(),
git_remote,
git_repo,
git_reset(),
git_restore(),
git_revert(),
git_signature(),
git_stash,
git_tag,
git_worktree
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.