Learn R Programming

gert (version 2.4.0)

user_is_configured: Test if a Git user is configured

Description

This function exists mostly to guard examples that rely on having a user configured, in order to make commits. user_is_configured() makes no distinction between local or global user config.

Usage

user_is_configured(repo = ".")

Value

TRUE if user.name and user.email are set locally or globally, FALSE otherwise.

Arguments

repo

An optional repo, in the sense of git_open().

Examples

Run this code
if (FALSE) { # interactive()
user_is_configured()
}

Run the code above in your browser using DataLab